pub struct Verification {
pub id: String,
pub identifier: String,
pub value: String,
pub expires_at: OffsetDateTime,
pub created_at: OffsetDateTime,
pub updated_at: OffsetDateTime,
}Expand description
Verification token or value used by flows such as email verification.
Fields
id: Stringidentifier: Stringvalue: Stringexpires_at: OffsetDateTimecreated_at: OffsetDateTimeupdated_at: OffsetDateTimeTrait Implementations
Sourceimpl Clone for Verification
impl Clone for Verification
Sourcefn clone(&self) -> Verification
fn clone(&self) -> Verification
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Verification
impl Debug for Verification
Sourceimpl<'de> Deserialize<'de> for Verification
impl<'de> Deserialize<'de> for Verification
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Verification, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Verification, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for Verification
impl PartialEq for Verification
Sourcefn eq(&self, other: &Verification) -> bool
fn eq(&self, other: &Verification) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for Verification
impl Serialize for Verification
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for Verification
impl StructuralPartialEq for Verification